@@ -4,12 +4,12 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-11-13'; # DATE
+our $DATE = '2023-11-01'; # DATE
 our $DIST = 'Acme-CPANModulesBundle-PERLANCAR'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 our $LIST = {
-    summary => 'Retired modules',
+    summary => 'List of my retired modules',
     description => <<'_',
 
 This is a list of some of the modules which I wrote but have now been retired
@@ -102,7 +102,7 @@ _
 };
 
 1;
-# ABSTRACT: Retired modules
+# ABSTRACT: List of my retired modules
 
 __END__
 
@@ -112,11 +112,11 @@ __END__
 
 =head1 NAME
 
-Acme::CPANModules::PERLANCAR::Retired - Retired modules
+Acme::CPANModules::PERLANCAR::Retired - List of my retired modules
 
 =head1 VERSION
 
-This document describes version 0.010 of Acme::CPANModules::PERLANCAR::Retired (from Perl distribution Acme-CPANModulesBundle-PERLANCAR), released on 2021-11-13.
+This document describes version 0.011 of Acme::CPANModules::PERLANCAR::Retired (from Perl distribution Acme-CPANModulesBundle-PERLANCAR), released on 2023-11-01.
 
 =head1 DESCRIPTION
 
@@ -133,14 +133,14 @@ don't purge most of the repos) if needed.
 
 =over
 
-=item * L<Data::Schema>
+=item L<Data::Schema>
 
 I wrote L<Data::Sah> which superseded this module since 2012.
 
 
 Alternate modules: L<Data::Sah>
 
-=item * L<Carp::Always::Dump>
+=item L<Carp::Always::Dump>
 
 This module is like L<Carp::Always>, but dumps complex arguments instead of
 just printing C<ARRAY(0x22f8160)> or something like that.
@@ -152,7 +152,7 @@ other tricks, all in a single package.
 
 Alternate modules: L<Devel::Confess>
 
-=item * L<Passwd::Unix::Alt>
+=item L<Passwd::Unix::Alt>
 
 I first wrote L<Passwd::Unix::Alt> (a fork of L<Passwd::Unix>) to support
 shadow passwd/group files, but later abandoned this fork due to a couple of
@@ -162,7 +162,7 @@ L<Unix::Passwd::File>.
 
 Alternate modules: L<Unix::Passwd::File>
 
-=item * L<Module::List::WithPath> - Like Module::List, but set hash values with paths
+=item L<Module::List::WithPath>
 
 Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
@@ -171,14 +171,14 @@ Superseded by L<PERLANCAR::Module::List>.
 
 Alternate modules: L<PERLANCAR::Module::List>
 
-=item * L<App::CreateSparseFile> - Create sparse file
+=item L<App::CreateSparseFile>
 
 Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
 I didn't know about the C<fallocate> command.
 
 
-=item * L<Log::Any::App> - An easy way to use Log::Any in applications
+=item L<Log::Any::App>
 
 Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
@@ -187,7 +187,7 @@ I've written L<Log::ger::App> to be its successor.
 
 Alternate modules: L<Log::ger::App>
 
-=item * L<Package::MoreUtil> - Package-related utilities
+=item L<Package::MoreUtil>
 
 Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
@@ -266,13 +266,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2018 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2021, 2020, 2019, 2018 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
